import { OpenAPIV3 } from 'openapi-types';
import React from 'react';
import { OpenAPIClientContext } from './types';
type CircularRefsIds = Map<OpenAPIV3.SchemaObject, string>;
interface OpenAPISchemaPropertyEntry {
    propertyName?: string;
    required?: boolean;
    schema: OpenAPIV3.SchemaObject;
}
/**
 * Render a property of an OpenAPI schema.
 */
export declare function OpenAPISchemaProperty(props: OpenAPISchemaPropertyEntry & {
    /** Set of objects already observed as parents */
    circularRefs?: CircularRefsIds;
    context: OpenAPIClientContext;
    className?: string;
}): React.JSX.Element;
/**
 * Render a set of properties of an OpenAPI schema.
 */
export declare function OpenAPISchemaProperties(props: {
    id?: string;
    properties: OpenAPISchemaPropertyEntry[];
    circularRefs?: CircularRefsIds;
    context: OpenAPIClientContext;
}): React.JSX.Element | null;
/**
 * Render a root schema (such as the request body or response body).
 */
export declare function OpenAPIRootSchema(props: {
    schema: OpenAPIV3.SchemaObject;
    context: OpenAPIClientContext;
}): React.JSX.Element;
/**
 * Render the enum value for a schema.
 */
export declare function OpenAPISchemaEnum(props: {
    enumValues: any[];
}): React.JSX.Element;
/**
 * Get the alternatives to display for a schema.
 */
export declare function getSchemaAlternatives(schema: OpenAPIV3.SchemaObject, ancestors?: Set<OpenAPIV3.SchemaObject>): null | [OpenAPIV3.SchemaObject[], OpenAPIV3.DiscriminatorObject | undefined];
export {};
